﻿#region License Information
/* HeuristicLab
 * Copyright (C) 2002-2011 Heuristic and Evolutionary Algorithms Laboratory (HEAL)
 *
 * This file is part of HeuristicLab.
 *
 * HeuristicLab is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * HeuristicLab is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with HeuristicLab. If not, see <http://www.gnu.org/licenses/>.
 */
#endregion

using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using HeuristicLab.DataImporter.Data;
using HeuristicLab.DataImporter.Data.CommandBase;
using HeuristicLab.DataImporter.Data.Model;
using HeuristicLab.DataImporter.Command.View;
using HeuristicLab.Persistence.Default.CompositeSerializers.Storable;

namespace HeuristicLab.DataImporter.Command {
  [StorableClass]
  [ViewableCommandInfoAttribute("Maximum", 1, ColumnGroupState.DoubleColumnSelected | ColumnGroupState.AnySelectedColumnNotSorted
    , "Aggregation", Position = 4, OptionsView = typeof(AggregationCommandView))]
  public class AggregateWithMaxCommand : AggregateCommandBase {
    private AggregateWithMaxCommand()
      : base(null,string.Empty,null) {
    }

    public AggregateWithMaxCommand(DataSet dataSet, string columnGroupName, int[] affectedColumns)
      : base(dataSet, columnGroupName, affectedColumns) {
    }

    public override string Description {
      get { return "Aggregate with max function"; }
    }

    protected override IComparable AggregationFunction(ColumnBase col, int startIndex, int endIndex) {
      IComparable maxValue = null;
      IComparable val;
      for (int i = startIndex; i < endIndex; i++) {
        val = col.GetValue(i);
        if (val != null) {
          if (maxValue == null || val.CompareTo(maxValue) > 0)
            maxValue = val;
        }
      }
      return maxValue;
    }
  }
}
